logger

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger struct {
	// contains filtered or unexported fields
}

Logger provides logging capabilities with file and console output

func NewLogger

func NewLogger(appName string) (*Logger, error)

NewLogger creates a new logger instance

func (*Logger) Close

func (l *Logger) Close() error

Close closes the logger's file handle

func (*Logger) DisplayCredits

func (l *Logger) DisplayCredits(banner string, appName string, appVersion string)

DisplayCredits displays the application credits/banner

func (*Logger) Error

func (l *Logger) Error(format string, args ...any)

Error logs an error message

func (*Logger) GetLogFilePath

func (l *Logger) GetLogFilePath() string

GetLogFilePath returns the path to the current log file

func (*Logger) Info

func (l *Logger) Info(format string, args ...any)

Info logs an informational message

func (*Logger) Warning

func (l *Logger) Warning(format string, args ...any)

Warning logs a warning message

Jump to