Documentation
¶
Index ¶
- type Logger
- func (l *Logger) Close() error
- func (l *Logger) DisplayCredits(banner string, appName string, appVersion string)
- func (l *Logger) Error(format string, args ...any)
- func (l *Logger) GetLogFilePath() string
- func (l *Logger) Info(format string, args ...any)
- func (l *Logger) Warning(format string, args ...any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger provides logging capabilities with file and console output
func (*Logger) DisplayCredits ¶
DisplayCredits displays the application credits/banner
func (*Logger) GetLogFilePath ¶
GetLogFilePath returns the path to the current log file
Click to show internal directories.
Click to hide internal directories.